@@ -56,10 +56,20 @@ class SharpClawSolver(Solver):
 
     .. attribute:: time_integrator
 
-        Time integrator to be used.
-        Euler: forward Euler method.
-        SSP33: 3-stages, 3rd-order SSP Runge-Kutta method.
-        SSP104: 10-stages, 4th-order SSP Runge-Kutta method.
+        Time integrator to be used. Currently implemented methods:
+
+        'Euler'  : 1st-order Forward Euler integration
+        'SSP33'  : 3rd-order strong stability preserving method of Shu & Osher
+        'SSP104' : 4th-order strong stability preserving method Ketcheson
+        'SSPMS32': 2nd-order strong stability preserving 3-step linear multistep method,
+                   using Euler for starting values
+        'SSPMS43': 3rd-order strong stability preserving 4-step linear multistep method
+                   using SSPRK22 for starting values
+        'RK'     : Arbitrary Runge-Kutta method, specified by setting `solver.a`
+                   and `solver.b` to the Butcher arrays of the method.
+        'LMM'    : Arbitrary linear multistep method, specified by setting the
+                   coefficient arrays `solver.alpha` and `solver.beta`.
+
         ``Default = 'SSP104'``
 
     .. attribute:: char_decomp
@@ -121,7 +131,22 @@ class SharpClawSolver(Solver):
         ``Default = False``
 
     """
-    
+    _sspcoeff = {
+       'Euler' :    1.0,
+       'SSP33':     1.0,
+       'SSP104' :   6.0,
+       'SSPMS32' :  0.5,
+       'SSPMS43' :  1./3.,
+       'RK':        None,
+       'LMM':       None
+       }
+
+    _cfl_default = {
+        'SSP104':   [2.45, 2.5],
+        'SSPMS32':  [0.16, 0.2],
+        'SSPMS43':  [0.14, 0.16]
+        }
+
     # ========================================================================
     #   Initialization routines
     # ========================================================================
@@ -140,27 +165,33 @@ class SharpClawSolver(Solver):
         self.kernel_language = 'Fortran'
         self.num_ghost = 3
         self.fwave = False
-        self.cfl_desired = 2.45
-        self.cfl_max = 2.5
+        self.cfl_desired = None
+        self.cfl_max = None
         self.dq_src = None
         self.call_before_step_each_stage = False
         self._mthlim = self.limiters
         self._method = None
-        self._rk_stages = None
+        self._registers = None
 
+        # Used only if time integrator is 'RK'
         self.a = None
         self.b = None
         self.c = None
-        
+
+        # Used only if time integrator is a multistep method
+        self.step_index = 1
+        self.alpha = None
+        self.beta = None
 
         # Call general initialization function
         super(SharpClawSolver,self).__init__(riemann_solver,claw_package)
         
     def setup(self,solution):
         """
-        Allocate RK stage arrays and fortran routine work arrays.
+        Allocate RK stage arrays or previous step solutions and fortran routine work arrays.
         """
-        self.num_ghost = (self.weno_order+1)/2
+        if self.lim_type == 2:
+            self.num_ghost = (self.weno_order+1)/2
 
         # This is a hack to deal with the fact that petsc4py
         # doesn't allow us to change the stencil_width (num_ghost)
@@ -168,8 +199,16 @@ class SharpClawSolver(Solver):
         state.set_num_ghost(self.num_ghost)
         # End hack
 
-        self._allocate_rk_stages(solution)
+        self._allocate_registers(solution)
         self._set_mthlim()
+        try:
+            if self.cfl_max is None:
+                self.cfl_desired  = self._cfl_default[self.time_integrator][0]
+                self.cfl_max  = self._cfl_default[self.time_integrator][1]
+            if self.cfl_desired is None:
+                self.cfl_desired = 0.9*self.cfl_max
+        except KeyError:
+            raise KeyError('Maximum CFL number is not provided.')
 
         state = solution.states[0]
  
@@ -204,12 +243,8 @@ class SharpClawSolver(Solver):
     def step(self,solution):
         """Evolve q over one time step.
 
-        Take on Runge-Kutta time step using the method specified by
-        self..time_integrator.  Currently implemented methods:
-
-        'Euler'  : 1st-order Forward Euler integration
-        'SSP33'  : 3rd-order strong stability preserving method of Shu & Osher
-        'SSP104' : 4th-order strong stability preserving method Ketcheson
+        Take one step with a Runge-Kutta or multistep method as specified by
+        `solver.time_integrator`.
         """
         state = solution.states[0]
 
@@ -222,79 +257,194 @@ class SharpClawSolver(Solver):
 
             elif self.time_integrator=='SSP33':
                 deltaq=self.dq(state)
-                self._rk_stages[0].q=state.q+deltaq
-                self._rk_stages[0].t =state.t+self.dt
+                self._registers[0].q=state.q+deltaq
+                self._registers[0].t =state.t+self.dt
 
                 if self.call_before_step_each_stage:
-                    self.before_step(self,self._rk_stages[0])
-                deltaq=self.dq(self._rk_stages[0])
-                self._rk_stages[0].q= 0.75*state.q + 0.25*(self._rk_stages[0].q+deltaq)
-                self._rk_stages[0].t = state.t+0.5*self.dt
+                    self.before_step(self,self._registers[0])
+                deltaq=self.dq(self._registers[0])
+                self._registers[0].q= 0.75*state.q + 0.25*(self._registers[0].q+deltaq)
+                self._registers[0].t = state.t+0.5*self.dt
 
                 if self.call_before_step_each_stage:
-                    self.before_step(self,self._rk_stages[0])
-                deltaq=self.dq(self._rk_stages[0])
-                state.q = 1./3.*state.q + 2./3.*(self._rk_stages[0].q+deltaq)
+                    self.before_step(self,self._registers[0])
+                deltaq=self.dq(self._registers[0])
+                state.q = 1./3.*state.q + 2./3.*(self._registers[0].q+deltaq)
 
 
             elif self.time_integrator=='SSP104':
-                s1=self._rk_stages[0]
-                s2=self._rk_stages[1]
-                s1.q = state.q.copy()
+                state.q = self.ssp104(state)
 
-                deltaq=self.dq(state)
-                s1.q = state.q + deltaq/6.
-                s1.t = state.t + self.dt/6.
 
-                for i in xrange(4):
-                    if self.call_before_step_each_stage:
-                        self.before_step(self,s1)
-                    deltaq=self.dq(s1)
-                    s1.q=s1.q + deltaq/6.
-                    s1.t =s1.t + self.dt/6.
-
-                s2.q = state.q/25. + 9./25 * s1.q
-                s1.q = 15. * s2.q - 5. * s1.q
-                s1.t = state.t + self.dt/3.
-
-                for i in xrange(4):
-                    if self.call_before_step_each_stage:
-                        self.before_step(self,s1)
-                    deltaq=self.dq(s1)
-                    s1.q=s1.q + deltaq/6.
-                    s1.t =s1.t + self.dt/6.
-                
-                if self.call_before_step_each_stage:
-                    self.before_step(self,s1)
-                deltaq = self.dq(s1)
-                state.q = s2.q + 0.6 * s1.q + 0.1 * deltaq
-                
             elif self.time_integrator=='RK':
                 # General RK with specified coefficients
-                # self._rk_stages[i].q actually stores f(y_i)
+                # self._registers[i].q actually stores dt*f(y_i)
                 num_stages = len(self.b)
                 for i in range(num_stages):
-                    self._rk_stages[i].q = state.q.copy()
+                    self._registers[i].q = state.q.copy()
                     for j in range(i):
-                        self._rk_stages[i].q += self.a[i,j]*self._rk_stages[j].q
-                    self._rk_stages[i].t = state.t + self.dt * self.c[i]
-                    self._rk_stages[i].q = self.dq(self._rk_stages[i])
+                        self._registers[i].q += self.a[i,j]*self._registers[j].q
+                    self._registers[i].t = state.t + self.dt * self.c[i]
+                    self._registers[i].q = self.dq(self._registers[i])
 
                 for j in range(num_stages):
-                    state.q += self.b[j]*self._rk_stages[j].q
+                    state.q += self.b[j]*self._registers[j].q
+
+
+            elif self.time_integrator == 'SSPMS32':
+                # Store initial solution
+                if self.step_index == 1:
+                    for i in range(2):
+                        self._registers[-2+i].dt = self.dt
+                    self._registers[-1].q = state.q.copy()
+
+                if self.step_index < 3:
+                    # Use Euler method for starting values
+                    deltaq = self.dq(state)
+                    state.q += deltaq
+                    self.step_index += 1
+                
+                else:
+                    omega = (self._registers[-2].dt + self._registers[-1].dt)/self.dt
+                    # ssp coefficient
+                    r = (omega-1.)/omega
+                    # method coefficients 
+                    delta = 1./omega**2
+                    beta = (omega+1.)/omega
+                    deltaq = self.dq(state)
+                    state.q = beta*(r*state.q + deltaq) + delta*self._registers[-3].q
+
+                # Update stored solutions
+                for i in range(2):
+                    self._registers[-3+i].q = self._registers[-2+i].q.copy()
+                    self._registers[-3+i].dt = self._registers[-2+i].dt
+                self._registers[-1].q = state.q.copy()
+                self._registers[-1].dt = self.dt
+
+
+            elif self.time_integrator == 'SSPMS43':
+                # Store initial solution
+                if self.step_index == 1:
+                    for i in range(3):
+                        self._registers[-3+i].dt = self.dt
+                    self._registers[-1].q = state.q.copy()
+
+                if self.step_index < 4:
+                    # Use SSP22 method for starting values
+                    import copy
+                    s1 = copy.deepcopy(state)
+                    s1.set_num_ghost(self.num_ghost)
+
+                    deltaq=self.dq(state)
+                    s1.q = state.q + deltaq
+                    s1.t = state.t + self.dt
+                    deltaq = self.dq(s1)
+                    state.q = 0.5*(state.q + s1.q + deltaq)
+
+                    self.step_index += 1
+                
+                else:
+                    H = self._registers[-3].dt + self._registers[-2].dt + self._registers[-1].dt
+                    omega3 = H/self.dt
+                    omega4 = omega3 + 1.
+                    # SSP coefficient
+                    r = (omega3-2.)/omega3
+                    # method coefficients
+                    delta0 = (4*omega4 - omega3**2)/omega3**3
+                    beta0 = omega4/omega3**2
+                    beta3 = omega4**2/omega3**2
+                    deltaq = self.dq(state)
+                    deltaqm4 = self.dq(self._registers[-4]) 
+                    state.q = beta3*(r*state.q + deltaq) + \
+                            (r*beta0+delta0)*self._registers[-4].q + beta0*deltaqm4
+
+                # Update stored solutions
+                for i in range(3):
+                    self._registers[-4+i].q = self._registers[-3+i].q.copy()
+                    self._registers[-4+i].dt = self._registers[-3+i].dt
+                self._registers[-1].q = state.q.copy()
+                self._registers[-1].dt = self.dt
+
+
+            elif self.time_integrator == 'LMM':
+                num_steps = len(self.alpha)
+
+                # Store initial solution
+                if self.step_index == 1:
+                    self._registers[-num_steps].q  = state.q.copy()
+                    self._registers[-num_steps].dq = self.dq(state)
+
+                if self.step_index < num_steps:
+                    # Using SSP104 for previous step values
+                    state.q = self.ssp104(state)
+                    self._registers[-num_steps+self.step_index].q = state.q.copy()
+                    self._registers[-num_steps+self.step_index].dq = self.dq(state)
+                    self.step_index += 1
+                else:
+                    # Update solution: alpha[-1] and beta[-1] correspond to solution at the previous step
+                    state.q = self.alpha[-1]*self._registers[-1].q + self.beta[-1]*self._registers[-1].dq
+                    for i in range(-num_steps,-1):
+                        state.q += self.alpha[i]*self._registers[i].q + self.beta[i]*self._registers[i].dq
+                        self._registers[i].q = self._registers[i+1].q.copy()
+                        self._registers[i].dq = self._registers[i+1].dq.copy()
+                    # Store current solution and function evaluation
+                    self._registers[-1].q = state.q.copy()
+                    self._registers[-1].dq = self.dq(state)
+
+
             else:
                 raise Exception('Unrecognized time integrator')
         except CFLError:
             return False
 
 
+    def ssp104(self,state):
+        if self.time_integrator == 'SSP104':
+            s1=self._registers[0]
+            s2=self._registers[1]
+            s1.q = state.q.copy()
+        elif self.time_integrator == 'LMM':
+            import copy
+            s1 = copy.deepcopy(state)
+            s1.set_num_ghost(self.num_ghost)
+            s2 = copy.deepcopy(s1)
+
+        deltaq=self.dq(state)
+        s1.q = state.q + deltaq/6.
+        s1.t = state.t + self.dt/6.
+
+        for i in xrange(4):
+            if self.call_before_step_each_stage:
+                self.before_step(self,s1)
+            deltaq=self.dq(s1)
+            s1.q=s1.q + deltaq/6.
+            s1.t =s1.t + self.dt/6.
+
+        s2.q = state.q/25. + 9./25 * s1.q
+        s1.q = 15. * s2.q - 5. * s1.q
+        s1.t = state.t + self.dt/3.
+
+        for i in xrange(4):
+            if self.call_before_step_each_stage:
+                self.before_step(self,s1)
+            deltaq=self.dq(s1)
+            s1.q=s1.q + deltaq/6.
+            s1.t =s1.t + self.dt/6.
+
+        if self.call_before_step_each_stage:
+            self.before_step(self,s1)
+        deltaq = self.dq(s1)
+ 
+        return s2.q + 0.6 * s1.q + 0.1 * deltaq
+
+
     def _set_mthlim(self):
         self._mthlim = self.limiters
         if not isinstance(self.limiters,list): self._mthlim=[self._mthlim]
         if len(self._mthlim)==1: self._mthlim = self._mthlim * self.num_waves
         if len(self._mthlim)!=self.num_waves:
             raise Exception('Length of solver.limiters is not equal to 1 or to solver.num_waves')
- 
+
        
     def dq(self,state):
         """
@@ -360,36 +510,78 @@ class SharpClawSolver(Solver):
         reconstruct.alloc_recon_workspace(maxnx,self.num_ghost,state.num_eqn,self.num_waves,
                                             clawparams.lim_type,clawparams.char_decomp)
 
-    def _allocate_rk_stages(self,solution):
+    def _allocate_registers(self,solution):
         r"""
-        Instantiate State objects for Runge--Kutta stages.
+        Instantiate State objects for Runge--Kutta stages and Linear Multistep method steps.
 
         This routine is only used by method-of-lines solvers (SharpClaw),
         not by the Classic solvers.  It allocates additional State objects
-        to store the intermediate stages used by Runge--Kutta time integrators.
+        to store the intermediate stages used by Runge--Kutta and Multistep 
+        time integrators.
 
         If we create a MethodOfLinesSolver subclass, this should be moved there.
         """
-        if self.time_integrator   == 'Euler':  nregisters=1
-        elif self.time_integrator == 'SSP33':  nregisters=2
-        elif self.time_integrator == 'SSP104': nregisters=3
-        elif self.time_integrator == 'RK': 
-            nregisters=len(self.b)+2
- 
+        # Generally the number of registers for the starting method should be at most 
+        # equal to the number of registers of the LMM
+        if self.time_integrator   == 'Euler':   nregisters=0
+        elif self.time_integrator == 'SSP33':   nregisters=1
+        elif self.time_integrator == 'SSP104':  nregisters=2
+        elif self.time_integrator == 'RK':      nregisters=len(self.b)+1
+        elif self.time_integrator == 'SSPMS32': nregisters=3
+        elif self.time_integrator == 'SSPMS43': nregisters=4
+        elif self.time_integrator == 'LMM':
+            nregisters=len(self.alpha)
+            self.dt_variable = False
+        else:
+            raise Exception('Unrecognized time intergrator')
+        
         state = solution.states[0]
         # use the same class constructor as the solution for the Runge Kutta stages
         State = type(state)
-        self._rk_stages = []
-        for i in xrange(nregisters-1):
+        self._registers = []
+        for i in xrange(nregisters):
             #Maybe should use State.copy() here?
-            self._rk_stages.append(State(state.patch,state.num_eqn,state.num_aux))
-            self._rk_stages[-1].problem_data       = state.problem_data
-            self._rk_stages[-1].set_num_ghost(self.num_ghost)
-            self._rk_stages[-1].t                = state.t
-            if state.num_aux > 0:
-                self._rk_stages[-1].aux              = state.aux
+            self._registers.append(State(state.patch,state.num_eqn,state.num_aux))
+            self._registers[-1].problem_data                = state.problem_data
+            self._registers[-1].set_num_ghost(self.num_ghost)
+            self._registers[-1].t                           = state.t
+            if state.num_aux > 0: self._registers[-1].aux   = state.aux
 
 
+    def get_cfl_max(self):
+        """
+        Set maximum CFL number for current step depending on time integrator
+        """
+        if self.time_integrator[:-2] == 'SSPMS' and self.step_index >= len(self._registers):
+            s = len(self._registers)-2
+            H = self._registers[-2].dt
+            for i in range(s):
+                H += self._registers[-3-i].dt
+            r = (H - s*self._registers[-1].dt)/H # ssp coefficient at the current step
+            sigma = r/self._sspcoeff[self.time_integrator]
+        else:
+            sigma = 1.0
+
+        return sigma * self.cfl_max
+
+    def get_dt_new(self):
+        """
+        Set time-step for next step depending on time integrator
+        """
+        # desired time-step 
+        dt_des = self.dt * self.cfl_desired / self.cfl.get_cached_max()
+
+        if self.time_integrator[:-2] == 'SSPMS' and self.step_index >= len(self._registers):
+            s = len(self._registers)-2
+            H = self._registers[-1].dt
+            for i in range(s):
+                H += self._registers[-2-i].dt
+            sigma = H / (self._sspcoeff[self.time_integrator]*H + s*dt_des)
+        else:
+            sigma = 1.0
+
+        return sigma * dt_des
+
 
 
 # ========================================================================
